// משתנה גלובלי לנגן הצף
let floatingPlayer = null;

// משתנה לשמירת קבצי וידאו שכבר נוספו להם כפתורים
const processedVideos = new Set();

// משתנה לשמירת ה-event listeners הפעילים
const activeListeners = new Map();

// ניקוי הזיכרון כשעוברים בין מיילים
const clearProcessedVideos = () => {
    processedVideos.clear();
};

// פונקציה לניקוי כל ה-listeners של הנגן הצף
const cleanupFloatingPlayer = () => {
    if (!floatingPlayer) return;
    
    console.log('מנקה משאבים של נגן הווידאו...');
    
    // הסרת event listeners מהמסמך
    const listeners = activeListeners.get(floatingPlayer);
    if (listeners) {
        listeners.forEach(({ event, handler, element }) => {
            element.removeEventListener(event, handler);
        });
        activeListeners.delete(floatingPlayer);
    }
    
    // ניקוי הנגן עצמו
    floatingPlayer.remove();
    floatingPlayer = null;
};

// פונקציה להוספת event listener עם מעקב
const addTrackedEventListener = (element, event, handler, options = {}) => {
    if (!element) return;
    
    element.addEventListener(event, handler, options);
    
    if (floatingPlayer) {
        if (!activeListeners.has(floatingPlayer)) {
            activeListeners.set(floatingPlayer, []);
        }
        
        activeListeners.get(floatingPlayer).push({
            event,
            handler,
            element
        });
    }
};

// פונקציה להסרת כל ה-event listeners שנוספו
const removeAllTrackedEventListeners = (element) => {
    if (!element) return;
    
    const listeners = activeListeners.get(element);
    if (listeners) {
        listeners.forEach(({ event, handler, element }) => {
            element.removeEventListener(event, handler);
        });
        activeListeners.delete(element);
    }
};

// פונקציה שמתחילה לעבוד ברגע שהדף נטען
function initializeVideoViewer() {
    console.log('מאתחל את צופה הווידאו...');
    
    // מאזין לשינויים בדף Gmail
    const observer = new MutationObserver((mutations) => {
        let shouldCheck = false;
        
        // בדיקה מהירה אם יש שינויים רלוונטיים
        for (const mutation of mutations) {
            if (mutation.type === 'childList' || 
                (mutation.type === 'attributes' && mutation.attributeName === 'class')) {
                if (mutation.target.querySelector('.bAK, .aZo') || 
                    mutation.target.classList?.contains('bAK') || 
                    mutation.target.classList?.contains('aZo')) {
                    console.log('זוהה אזור קבצים מצורפים...');
                    shouldCheck = true;
                    break;
                }
            }
        }
        
        // רק אם נמצאו שינויים רלוונטיים
        if (shouldCheck) {
            clearProcessedVideos();
            // נריץ את הבדיקה מיד במקום להשתמש ב-debounce
            checkForAttachments();
        }
    });

    // הגדרת תצפית ממוקדת יותר
    observer.observe(document.body, {
        childList: true,
        subtree: true,
        attributes: true,
        attributeFilter: ['class']
    });

    // בדיקה ראשונית
    console.log('מבצע בדיקה ראשונית של קבצים מצורפים...');
    checkForAttachments();
    
    // ניקוי כשעוזבים את הדף
    window.addEventListener('unload', () => {
        observer.disconnect();
        if (floatingPlayer) {
            cleanupFloatingPlayer();
        }
    });
}

// בדיקת קבצים מצורפים
function checkForAttachments() {
    console.log('מחפש קבצים מצורפים...');
    // מחפש את אזור הקבצים המצורפים
    const attachmentAreas = document.querySelectorAll('.bAK, .aZo');
    console.log('נמצאו אזורי קבצים:', attachmentAreas.length);

    attachmentAreas.forEach(area => {
        // אם כבר טיפלנו באזור הזה, נדלג עליו
        const processed = area.querySelector('.video-viewer-button');
        if (processed) {
            console.log('אזור כבר מכיל כפתור צפייה, מדלג...');
            return;
        }
        
        // מחפש את כל הקישורים באזור הקבצים המצורפים
        const links = area.querySelectorAll('a[href]');
        console.log('נמצאו קישורים:', links.length);

        links.forEach(link => {
            const href = link.href;
            if (!href || processedVideos.has(href)) {
                console.log('קישור כבר עובד או חסר:', href);
                return;
            }

            const filename = link.getAttribute('download') || link.innerText;
            console.log('בודק קובץ:', filename);
            
            if (!isVideoFile(filename)) {
                console.log('לא קובץ וידאו:', filename);
                return;
            }

            console.log('נמצא קובץ וידאו:', filename);
            // בדיקת תקינות הקובץ
            chrome.runtime.sendMessage({ 
                action: 'getVideoInfo',
                url: href 
            }, response => {
                console.log('תשובה מהשרת:', response);
                if (response && response.success) {
                    processedVideos.add(href);
                    addViewButton(link);
                    console.log('נוסף כפתור צפייה לקובץ:', filename);
                } else {
                    console.error('שגיאה בקבלת מידע על הוידאו:', response?.error || 'שגיאה לא ידועה');
                }
            });
        });
    });
}

// בודק אם הקובץ הוא קובץ וידאו
function isVideoFile(filename) {
    if (!filename) return false;
    
    // מנקה את שם הקובץ
    filename = filename.toLowerCase().trim();
    
    // מסיר טקסט "תצוגה מקדימה של הקובץ המצורף" אם קיים
    if (filename.includes('תצוגה מקדימה של הקובץ המצורף')) {
        filename = filename.split('תצוגה מקדימה של הקובץ המצורף')[1].trim();
    }
    
    console.log('בודק סיומת עבור:', filename);
    
    // בודק סיומות נפוצות של קבצי וידאו
    const videoExtensions = [
        '.mp4', '.avi', '.mov', '.wmv', '.flv', '.mkv', '.webm', 
        '.m4v', '.mpeg', '.mpg', '.3gp', '.3g2'
    ];
    
    return videoExtensions.some(ext => filename.endsWith(ext));
}

// הוספת כפתור צפייה לקישור
function addViewButton(link) {
    // בדיקה אם כבר יש כפתור צפייה
    const existingButton = link.parentElement.querySelector('.video-viewer-button');
    if (existingButton) {
        console.log('כפתור צפייה כבר קיים');
        return;
    }

    // ניקוי שם הקובץ והקישור
    const fileName = link.getAttribute('download') || link.innerText;
    const cleanFileName = cleanupFileName(fileName);
    
    // קבלת ה-URL האמיתי של הקובץ
    const videoUrl = link.href;
    if (!videoUrl || videoUrl.includes('#inbox')) {
        console.error('URL לא תקין:', videoUrl);
        return;
    }

    console.log('יוצר כפתור צפייה חדש');
    const button = document.createElement('button');
    button.className = 'video-viewer-button';
    button.textContent = 'צפה בוידאו';
    button.style.cssText = 'margin-right: 10px; padding: 5px 10px; background-color: #1a73e8; color: white; border: none; border-radius: 4px; cursor: pointer;';

    button.addEventListener('click', async (e) => {
        e.preventDefault();
        e.stopPropagation();
        
        try {
            // הגדרת timeout לבקשת הרשת
            const timeoutPromise = new Promise((_, reject) => {
                setTimeout(() => reject(new Error('תם הזמן המוקצב לטעינת המידע')), 30000);
            });

            // בדיקת תקינות הקובץ דרך background script עם timeout
            const response = await Promise.race([
                new Promise((resolve, reject) => {
                    chrome.runtime.sendMessage(
                        { action: 'getVideoInfo', url: videoUrl },
                        response => {
                            if (chrome.runtime.lastError) {
                                reject(chrome.runtime.lastError);
                                return;
                            }
                            if (!response || !response.success) {
                                reject(new Error(response?.error || 'שגיאה לא ידועה'));
                                return;
                            }
                            resolve(response);
                        }
                    );
                }),
                timeoutPromise
            ]);

            // אם הגענו לכאן, הקובץ תקין ואפשר להציג אותו
            const storagePromise = new Promise((resolve, reject) => {
                const timeoutId = setTimeout(() => reject(new Error('תם הזמן המוקצב לטעינת ההגדרות')), 5000);
                chrome.storage.sync.get(['openInNewTab'], (result) => {
                    clearTimeout(timeoutId);
                    resolve(result);
                });
            });

            const settings = await storagePromise;
            
            if (settings.openInNewTab) {
                // פתיחה בטאב חדש
                const playerUrl = chrome.runtime.getURL('player.html');
                const fullUrl = `${playerUrl}?video=${encodeURIComponent(videoUrl)}&title=${encodeURIComponent(cleanFileName)}`;
                window.open(fullUrl, '_blank');
            } else {
                // פתיחה בחלון צף
                showVideoPlayer(videoUrl, cleanFileName);
            }
        } catch (error) {
            console.error('שגיאה בטעינת הוידאו:', error.message);
            
            // טיפול בשגיאות ספציפיות
            let errorMessage = error.message;
            if (error.message.includes('תם הזמן')) {
                errorMessage = 'הפעולה נכשלה עקב זמן המתנה ארוך מדי';
            } else if (!navigator.onLine) {
                errorMessage = 'אין חיבור לאינטרנט';
            }

            // אם זו שגיאת 404 אבל יש לנו URL תקין, ננסה להציג בכל זאת
            if (error.message.includes('404') && videoUrl && !videoUrl.includes('#inbox')) {
                console.log('מנסה להציג את הוידאו למרות השגיאה');
                chrome.storage.sync.get(['openInNewTab'], (result) => {
                    if (result.openInNewTab) {
                        const playerUrl = chrome.runtime.getURL('player.html');
                        const fullUrl = `${playerUrl}?video=${encodeURIComponent(videoUrl)}&title=${encodeURIComponent(cleanFileName)}`;
                        window.open(fullUrl, '_blank');
                    } else {
                        showVideoPlayer(videoUrl, cleanFileName);
                    }
                });
                return;
            }

            // הצגת הודעת שגיאה למשתמש
            const errorElement = document.createElement('div');
            errorElement.style.cssText = `
                position: fixed;
                top: 20px;
                left: 50%;
                transform: translateX(-50%);
                background: #dc3545;
                color: white;
                padding: 10px 20px;
                border-radius: 4px;
                z-index: 10000;
                font-family: Arial, sans-serif;
                box-shadow: 0 2px 4px rgba(0,0,0,0.2);
            `;
            errorElement.textContent = 'שגיאה בטעינת הוידאו: ' + errorMessage;
            document.body.appendChild(errorElement);
            
            // הסרת ההודעה אחרי 5 שניות
            setTimeout(() => {
                errorElement.remove();
            }, 5000);
        }
    });

    // הוספת הכפתור ליד הקישור
    link.parentElement.insertBefore(button, link.nextSibling);
    console.log('הכפתור נוסף בהצלחה');
}

// ניקוי שם הקובץ
function cleanupFileName(fileName) {
    // הסרת טקסט "תצוגה מקדימה של הקובץ המצורף" אם קיים
    let cleanName = fileName.replace('תצוגה מקדימה של הקובץ המצורף', '').trim();
    
    // הסרת גודל הקובץ מהשם (למשל "25 MB")
    cleanName = cleanName.replace(/\s+\d+(\.\d+)?\s*(MB|KB|GB|TB)/i, '').trim();
    
    // מוצא את ההופעה הראשונה של סיומת הקובץ ומסיר את כל מה שאחריה
    const extensionMatch = cleanName.match(/\.(mp4|webm|ogg|mov|avi|wmv|flv|mkv)/i);
    if (extensionMatch) {
        const firstExtensionIndex = cleanName.indexOf(extensionMatch[0]);
        cleanName = cleanName.substring(0, firstExtensionIndex + extensionMatch[0].length);
    }
    
    return cleanName;
}

// פונקציה לחישוב מיקום החלון
function calculateWindowPosition(container, position = 'top-right') {
    // מידות ברירת מחדל של החלון
    const defaultWidth = 400;
    const defaultHeight = 300;
    const margin = 20;

    // קבלת מידות החלון והמסך
    const windowWidth = window.innerWidth;
    const windowHeight = window.innerHeight;
    const containerWidth = container.offsetWidth || defaultWidth;
    const containerHeight = container.offsetHeight || defaultHeight;

    // חישוב מיקומים אפשריים
    const positions = {
        'top-left': {
            left: margin,
            top: margin
        },
        'top-center': {
            left: (windowWidth - containerWidth) / 2,
            top: margin
        },
        'top-right': {
            left: windowWidth - containerWidth - margin,
            top: margin
        },
        'middle-left': {
            left: margin,
            top: (windowHeight - containerHeight) / 2
        },
        'middle-center': {
            left: (windowWidth - containerWidth) / 2,
            top: (windowHeight - containerHeight) / 2
        },
        'middle-right': {
            left: windowWidth - containerWidth - margin,
            top: (windowHeight - containerHeight) / 2
        },
        'bottom-left': {
            left: margin,
            top: windowHeight - containerHeight - margin
        },
        'bottom-center': {
            left: (windowWidth - containerWidth) / 2,
            top: windowHeight - containerHeight - margin
        },
        'bottom-right': {
            left: windowWidth - containerWidth - margin,
            top: windowHeight - containerHeight - margin
        }
    };

    // קבלת המיקום הרצוי או ברירת מחדל
    const pos = positions[position] || positions['top-right'];

    // וידוא שהחלון נשאר בתוך גבולות המסך
    return {
        left: Math.max(margin, Math.min(pos.left, windowWidth - containerWidth - margin)),
        top: Math.max(margin, Math.min(pos.top, windowHeight - containerHeight - margin))
    };
}

// יצירת נגן וידאו צף
function showVideoPlayer(videoUrl, title) {
    // ניקוי נגן קודם אם קיים
    if (floatingPlayer) {
        cleanupFloatingPlayer();
    }

    // בדיקת תקינות ה-URL
    try {
        const url = new URL(videoUrl);
        if (!url.hostname.includes('mail.google.com') && 
            !url.hostname.includes('googleusercontent.com')) {
            console.error('URL לא מורשה:', videoUrl);
            return;
        }
    } catch (error) {
        console.error('URL לא תקין:', error);
        return;
    }

    // יצירת מיכל הנגן
    const playerContainer = document.createElement('div');
    playerContainer.className = 'floating-video-player';
    playerContainer.style.cssText = `
        position: fixed;
        width: 400px;
        background: #000;
        border-radius: 8px;
        box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        z-index: 9999;
        overflow: hidden;
    `;

    // יצירת כותרת הנגן
    const header = document.createElement('div');
    header.style.cssText = `
        display: flex;
        justify-content: space-between;
        align-items: center;
        padding: 8px;
        background: #1a1a1a;
        color: white;
        cursor: move;
    `;

    const titleElement = document.createElement('div');
    titleElement.textContent = title;
    titleElement.style.cssText = `
        margin-right: 8px;
        font-size: 14px;
        white-space: nowrap;
        overflow: hidden;
        text-overflow: ellipsis;
        max-width: 300px;
    `;

    const controls = document.createElement('div');
    controls.style.cssText = 'display: flex; gap: 4px;';

    // כפתור מסך מלא
    const fullscreenButton = document.createElement('button');
    fullscreenButton.textContent = '⛶';
    fullscreenButton.style.cssText = `
        background: none;
        border: none;
        color: white;
        cursor: pointer;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 16px;
    `;

    // כפתור סגירה
    const closeButton = document.createElement('button');
    closeButton.className = 'close-button';
    closeButton.textContent = '×';
    closeButton.style.cssText = `
        background: none;
        border: none;
        color: white;
        cursor: pointer;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 18px;
    `;

    controls.appendChild(fullscreenButton);
    controls.appendChild(closeButton);
    header.appendChild(titleElement);
    header.appendChild(controls);

    // יצירת נגן הוידאו
    const video = document.createElement('video');
    video.src = videoUrl;
    video.controls = true;
    video.style.cssText = 'width: 100%; height: calc(100% - 40px); background: black;';
    video.autoplay = true;

    // הוספת האלמנטים למיכל
    playerContainer.appendChild(header);
    playerContainer.appendChild(video);

    // הוספת המיכל לדף
    document.body.appendChild(playerContainer);

    // קביעת מיקום התחלתי לפי ההגדרות
    chrome.storage.sync.get(['defaultPosition'], (result) => {
        const position = result.defaultPosition || 'top-right';
        console.log('מיקום נבחר:', position);
        
        // חישוב המיקום
        const { left, top } = calculateWindowPosition(playerContainer, position);
        console.log('מיקום מחושב:', { left, top });
        
        // הגדרת המיקום ללא אנימציה
        playerContainer.style.left = left + 'px';
        playerContainer.style.top = top + 'px';
    });

    // טיפול במסך מלא
    let isFullscreen = false;
    let previousSize = null;

    fullscreenButton.addEventListener('click', () => {
        if (!isFullscreen) {
            previousSize = {
                width: playerContainer.style.width,
                height: playerContainer.style.height,
                top: playerContainer.style.top,
                left: playerContainer.style.left
            };
            
            playerContainer.style.width = '100%';
            playerContainer.style.height = '100%';
            playerContainer.style.top = '0';
            playerContainer.style.left = '0';
            fullscreenButton.textContent = '⧉';
        } else {
            Object.assign(playerContainer.style, previousSize);
            fullscreenButton.textContent = '⛶';
        }
        isFullscreen = !isFullscreen;
    });

    const cleanup = () => {
        console.log('מנקה משאבים של נגן הווידאו...');
        
        // ניקוי ResizeObserver
        resizeObserver.disconnect();
        
        // הסרת כל ה-event listeners שנוספו
        removeAllTrackedEventListeners(playerContainer);
        
        // הסרת event listeners של גרירה
        document.removeEventListener('mousemove', dragHandler);
        document.removeEventListener('mouseup', dragEndHandler);
        
        // איפוס המשתנה הגלובלי
        floatingPlayer = null;

        // ניקוי ה-mutation observer
        if (mutationObserver) {
            mutationObserver.disconnect();
        }
    };

    addTrackedEventListener(closeButton, 'click', () => {
        cleanup();
        playerContainer.remove();
    });

    // הוספת אפשרות גרירה
    let isDragging = false;
    let currentX;
    let currentY;
    let initialX;
    let initialY;

    let dragStartHandler = (e) => {
        if (isFullscreen || e.target.tagName === 'BUTTON') return;
        
        initialX = e.clientX - playerContainer.offsetLeft;
        initialY = e.clientY - playerContainer.offsetTop;
        
        if (e.target === header || header.contains(e.target)) {
            isDragging = true;
        }
    };

    let dragHandler = (e) => {
        if (!isDragging) return;

        const dx = e.clientX - initialX;
        const dy = e.clientY - initialY;

        // הגבלת הגרירה לגבולות המסך
        const margin = 20;
        const maxX = window.innerWidth - playerContainer.offsetWidth - margin;
        const maxY = window.innerHeight - playerContainer.offsetHeight - margin;

        const newLeft = Math.max(margin, Math.min(dx, maxX));
        const newTop = Math.max(margin, Math.min(dy, maxY));

        playerContainer.style.left = newLeft + 'px';
        playerContainer.style.top = newTop + 'px';
    };

    let dragEndHandler = () => {
        isDragging = false;
    };

    addTrackedEventListener(header, 'mousedown', dragStartHandler);
    addTrackedEventListener(document, 'mousemove', dragHandler);
    addTrackedEventListener(document, 'mouseup', dragEndHandler);

    // הוספת ידיות לשינוי גודל
    addResizeHandles(playerContainer);

    // האזנה לשינויים בדף Gmail
    const resizeObserver = new ResizeObserver(() => {
        if (!isFullscreen) {
            const { left, top } = calculateWindowPosition(playerContainer);
            playerContainer.style.left = `${left}px`;
            playerContainer.style.top = `${top}px`;
        }
    });

    resizeObserver.observe(document.body);
    
    // מעקב אחרי הסרת החלון מה-DOM
    const mutationObserver = new MutationObserver((mutations) => {
        for (const mutation of mutations) {
            for (const node of mutation.removedNodes) {
                if (node === playerContainer) {
                    cleanup();
                    return;
                }
            }
        }
    });

    // מעקב אחרי שינויים בכל ה-DOM
    mutationObserver.observe(document.body, {
        childList: true,
        subtree: true
    });
    
    // שמירת הנגן במשתנה הגלובלי
    floatingPlayer = playerContainer;
}

// הוספת ידיות לשינוי גודל
function addResizeHandles(playerContainer) {
    const handles = [
        'n', 'e', 's', 'w',
        'ne', 'nw', 'se', 'sw'
    ];

    handles.forEach(direction => {
        const handle = document.createElement('div');
        handle.className = `resize-handle ${direction}`;
        handle.style.cssText = `
            position: absolute;
            z-index: 10000;
            ${direction.includes('n') ? 'top: -5px;' : ''}
            ${direction.includes('s') ? 'bottom: -5px;' : ''}
            ${direction.includes('e') ? 'right: -5px;' : ''}
            ${direction.includes('w') ? 'left: -5px;' : ''}
            ${direction.includes('n') || direction.includes('s') ? 'height: 10px;' : ''}
            ${direction.includes('e') || direction.includes('w') ? 'width: 10px;' : ''}
            ${direction.length === 2 ? 'width: 10px; height: 10px;' : ''}
            cursor: ${direction}-resize;
        `;
        playerContainer.appendChild(handle);
    });

    let isResizing = false;
    let currentHandle = null;
    let startX, startY;
    let initialX, initialY;
    let startWidth, startHeight;
    let startLeft, startTop;

    const minWidth = 300;
    const minHeight = 200;
    const margin = 20;

    handles.forEach(direction => {
        const handle = playerContainer.querySelector(`.${direction}`);
        
        addTrackedEventListener(handle, 'mousedown', (e) => {
            isResizing = true;
            currentHandle = direction;
            
            startX = e.clientX;
            startY = e.clientY;
            startWidth = playerContainer.offsetWidth;
            startHeight = playerContainer.offsetHeight;
            startLeft = playerContainer.offsetLeft;
            startTop = playerContainer.offsetTop;

            addTrackedEventListener(document, 'mousemove', handleResize);
            addTrackedEventListener(document, 'mouseup', stopResize);
            
            e.preventDefault();
            e.stopPropagation();
        });
    });

    function handleResize(e) {
        if (!isResizing) return;

        const dx = e.clientX - startX;
        const dy = e.clientY - startY;

        let newWidth = startWidth;
        let newHeight = startHeight;
        let newLeft = startLeft;
        let newTop = startTop;

        const maxWidth = window.innerWidth - margin - newLeft;
        const maxHeight = window.innerHeight - margin - newTop;

        // שינוי רוחב מצד ימין
        if (currentHandle.includes('e')) {
            newWidth = Math.min(Math.max(minWidth, startWidth + dx), window.innerWidth - startLeft - margin);
        }
        // שינוי רוחב מצד שמאל
        if (currentHandle.includes('w')) {
            const proposedWidth = Math.min(Math.max(minWidth, startWidth - dx), startLeft + startWidth - margin);
            if (proposedWidth !== newWidth) {
                newLeft = Math.min(Math.max(margin, startLeft + dx), startLeft + startWidth - minWidth);
                newWidth = startLeft + startWidth - newLeft;
            }
        }
        // שינוי גובה מלמטה
        if (currentHandle.includes('s')) {
            newHeight = Math.min(Math.max(minHeight, startHeight + dy), window.innerHeight - startTop - margin);
        }
        // שינוי גובה מלמעלה
        if (currentHandle.includes('n')) {
            const proposedHeight = Math.min(Math.max(minHeight, startHeight - dy), startTop + startHeight - margin);
            if (proposedHeight !== newHeight) {
                newTop = Math.min(Math.max(margin, startTop + dy), startTop + startHeight - minHeight);
                newHeight = startTop + startHeight - newTop;
            }
        }

        // עדכון מיקום וגודל
        playerContainer.style.width = `${newWidth}px`;
        playerContainer.style.height = `${newHeight}px`;
        playerContainer.style.left = `${newLeft}px`;
        playerContainer.style.top = `${newTop}px`;
    }

    function stopResize() {
        isResizing = false;
        document.removeEventListener('mousemove', handleResize);
        document.removeEventListener('mouseup', stopResize);
    }

    return handles;
}

// האזנה להודעות מה-popup
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
    // וידוא שההודעה מגיעה מהתוסף עצמו
    if (!sender.id || sender.id !== chrome.runtime.id) {
        console.error('נדחתה הודעה ממקור לא מורשה');
        return;
    }

    try {
        if (message.action === 'updateDefaultPosition' && floatingPlayer) {
            const { left, top } = calculateWindowPosition(floatingPlayer, message.position);
            floatingPlayer.style.left = `${left}px`;
            floatingPlayer.style.top = `${top}px`;
        } else if (message.action === 'updateOpenInNewTab') {
            // אם שינו להגדרת טאב חדש וקיים חלון צף, נסגור אותו
            if (message.openInNewTab && floatingPlayer) {
                cleanupFloatingPlayer();
            }
        }
    } catch (error) {
        console.error('שגיאה בטיפול בהודעה:', error);
    }
});

// ניקוי listeners בעת סגירת הדף
window.addEventListener('unload', () => {
    if (floatingPlayer) {
        cleanupFloatingPlayer();
    }
});

// התחלת האתחול
initializeVideoViewer();
