// קבלת פרמטרים מה-URL
function initializePlayer() {
    const urlParams = new URLSearchParams(window.location.search);
    const videoUrl = urlParams.get('video');
    const videoTitle = urlParams.get('title');

    // בדיקת תקינות הפרמטרים
    if (!videoUrl) {
        showError('לא נמצאה כתובת וידאו תקינה');
        return;
    }

    try {
        // בדיקה שה-URL תקין
        new URL(videoUrl);
    } catch (e) {
        showError('כתובת הווידאו אינה תקינה');
        return;
    }

    // הגדרת כותרת הדף
    document.title = videoTitle || 'נגן וידאו';

    // הגדרת כותרת הסרטון
    const titleElement = document.querySelector('.title-text');
    if (videoTitle) {
        titleElement.textContent = videoTitle;
    } else {
        document.querySelector('.video-title').style.display = 'none';
    }

    // הגדרת מקור הווידאו
    const videoElement = document.querySelector('video');
    const loadingElement = document.getElementById('loading');
    
    if (videoElement) {
        // הגדרת timeout לטעינת הווידאו
        const loadTimeout = setTimeout(() => {
            if (!videoElement.readyState) {
                showError('תם הזמן המוקצב לטעינת הווידאו');
            }
        }, 30000); // 30 שניות timeout

        // טיפול בשגיאות טעינה
        videoElement.addEventListener('error', (e) => {
            clearTimeout(loadTimeout);
            let errorMessage = 'שגיאה בטעינת הסרטון';
            
            if (videoElement.error) {
                switch (videoElement.error.code) {
                    case MediaError.MEDIA_ERR_ABORTED:
                        errorMessage = 'הטעינה בוטלה';
                        break;
                    case MediaError.MEDIA_ERR_NETWORK:
                        errorMessage = 'אירעה שגיאת רשת';
                        break;
                    case MediaError.MEDIA_ERR_DECODE:
                        errorMessage = 'לא ניתן לפענח את קובץ הווידאו';
                        break;
                    case MediaError.MEDIA_ERR_SRC_NOT_SUPPORTED:
                        errorMessage = 'פורמט הווידאו אינו נתמך';
                        break;
                }
            }
            
            showError(errorMessage);
            console.error('שגיאת וידאו:', videoElement.error);
        });

        // הסתרת מסך טעינה כשהווידאו מוכן
        videoElement.addEventListener('loadeddata', () => {
            clearTimeout(loadTimeout);
            if (loadingElement) {
                loadingElement.style.display = 'none';
            }
        });

        // טיפול במצב של ניתוק מהרשת
        window.addEventListener('offline', () => {
            if (videoElement.networkState === HTMLMediaElement.NETWORK_LOADING) {
                showError('אין חיבור לאינטרנט');
            }
        });

        // ניסיון לטעון מחדש כשהחיבור חוזר
        window.addEventListener('online', () => {
            if (videoElement.networkState === HTMLMediaElement.NETWORK_NO_SOURCE ||
                videoElement.networkState === HTMLMediaElement.NETWORK_EMPTY) {
                videoElement.load();
                hideError();
                if (loadingElement) {
                    loadingElement.style.display = 'flex';
                }
            }
        });

        // הגדרת מקור הווידאו
        videoElement.src = decodeURIComponent(videoUrl);

        // הוספת פונקציונליות לכפתורי השליטה
        const downloadButton = document.querySelector('.control-button[title="הורדת הסרטון"]');
        if (downloadButton) {
            downloadButton.addEventListener('click', () => {
                const link = document.createElement('a');
                link.href = videoUrl;
                link.download = videoTitle || 'video';
                link.click();
            });
        }

        const shareButton = document.querySelector('.control-button[title="שיתוף"]');
        if (shareButton) {
            shareButton.addEventListener('click', async () => {
                try {
                    if (navigator.share) {
                        await navigator.share({
                            title: videoTitle || 'שיתוף וידאו',
                            url: videoUrl
                        });
                    } else {
                        // העתקה ללוח אם share API לא זמין
                        await navigator.clipboard.writeText(videoUrl);
                        showNotification('הקישור הועתק ללוח');
                    }
                } catch (error) {
                    console.error('שגיאה בשיתוף:', error);
                }
            });
        }

        const settingsButton = document.querySelector('.control-button[title="הגדרות"]');
        if (settingsButton) {
            settingsButton.addEventListener('click', () => {
                // כאן אפשר להוסיף תפריט הגדרות
                console.log('תפריט הגדרות - יתווסף בעתיד');
            });
        }
    }
}

// פונקציה להצגת שגיאה
function showError(message) {
    const errorElement = document.getElementById('error-message');
    const errorText = errorElement.querySelector('.error-text');
    if (errorElement && errorText) {
        errorText.textContent = message;
        errorElement.style.display = 'flex';
        document.getElementById('loading').style.display = 'none';
    }
}

// פונקציה להסתרת שגיאה
function hideError() {
    const errorElement = document.getElementById('error-message');
    if (errorElement) {
        errorElement.style.display = 'none';
    }
}

// פונקציה להצגת התראה
function showNotification(message) {
    const notification = document.createElement('div');
    notification.style.cssText = `
        position: fixed;
        bottom: 20px;
        left: 50%;
        transform: translateX(-50%);
        background: rgba(0, 0, 0, 0.9);
        color: white;
        padding: 12px 24px;
        border-radius: 8px;
        font-size: 14px;
        z-index: 1000;
        animation: fadeInOut 3s ease forwards;
    `;
    notification.textContent = message;
    document.body.appendChild(notification);

    setTimeout(() => {
        notification.remove();
    }, 3000);
}

// הוספת אנימציית fadeInOut
const style = document.createElement('style');
style.textContent = `
    @keyframes fadeInOut {
        0% { opacity: 0; transform: translate(-50%, 20px); }
        10% { opacity: 1; transform: translate(-50%, 0); }
        90% { opacity: 1; transform: translate(-50%, 0); }
        100% { opacity: 0; transform: translate(-50%, -20px); }
    }
`;
document.head.appendChild(style);

// הפעלת האתחול כשהדף נטען
document.addEventListener('DOMContentLoaded', initializePlayer);
